==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/ka_GE.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "წესის მოკლე აღწერა",
    "Add rule" : "წესის დამატება",
    "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
    "Save" : "შენახვა",
    "Saving…" : "მიმდინარეობს დამახსოვრება...",
    "Saved" : "შენახულია",
    "Saving failed:" : "შენახვა ვერ მოხერხდა:",
    "Add rule group" : "ჯგუფის წესის დამატება",
    "File MIME type" : "ფაილის MIME სახეობა",
    "is" : "არის",
    "is not" : "არ არის",
    "matches" : "ემთხვევა",
    "does not match" : "არ ემთხვევა",
    "Example: {placeholder}" : "მაგალითი: {placeholder}",
    "File size (upload)" : "ფაილის ზომა (ატვირთვა)",
    "less" : "უფრო ნაკლები",
    "less or equals" : "უფრო ნაკლები ან ტოლი",
    "greater or equals" : "უფრო მეტი ან ტოლი",
    "greater" : "უფრო მეტი",
    "File system tag" : "ფაილის სისტემური ტეგი",
    "is tagged with" : "დატეგილია როგორც",
    "is not tagged with" : "არაა დატეგილი როგორც",
    "Select tag…" : "აირჩიეთ ტეგი...",
    "Request remote address" : "დისტანციური მისამართის მოთხოვნა",
    "matches IPv4" : "ემთხვევა IPv4-ს",
    "does not match IPv4" : "არ ემთხვევა IPv4-ს",
    "matches IPv6" : "ემთხვევა IPv6-ს",
    "does not match IPv6" : "არ ემთხვევა IPv6-ს",
    "Request time" : "მოთხოვნის დრო",
    "between" : "შორის",
    "not between" : "არა შორის",
    "Start" : "დაწყება",
    "End" : "დამთავრება",
    "Select timezone…" : "აირჩიეთ დროის სარტყელი...",
    "Request URL" : "მოთხოვნის URL",
    "Predefined URLs" : "წინასწარ განსაზღვრული URL-ები",
    "Files WebDAV" : "ფაილები WebDAV",
    "Request user agent" : "მოთხოვნის მომხმარებლის აგენტი",
    "Sync clients" : "სინქ. კლიენტები",
    "Android client" : "Android კლიენტი",
    "iOS client" : "iOS კლიენტი",
    "Desktop client" : "დესკტოპ კლიენტი",
    "User group membership" : "მომხმარებლის ჯგუფის წევრიანობა",
    "is member of" : "არის წევრი ჯგუფისა",
    "is not member of" : "არ არის წევრი ჯგუფისა",
    "The given operator is invalid" : "მოცემული ოპერატორი არაა სწორი",
    "The given regular expression is invalid" : "მოცემული რეგულარული გამოსახულება არაა სწორი",
    "The given file size is invalid" : "მოცემული ფაილის ზომა არაა სწორი",
    "The given tag id is invalid" : "მოცემული ტეგის id არაა სწორი",
    "The given IP range is invalid" : "მოცემული IP დიაპაზონი არაა სწორი",
    "The given IP range is not valid for IPv4" : "მოცემული IP დიაპაზონი არაა სწორი IPv4-ისთვის",
    "The given IP range is not valid for IPv6" : "მოცემული IP დიაპაზონი არაა სწორი IPv6-ისთვის",
    "The given time span is invalid" : "მოცემული დროის ინტერვალი არაა სწორი",
    "The given start time is invalid" : "მოცემული საწყისი დრო არაა სწორი",
    "The given end time is invalid" : "მოცემული დროის დასასრული არაა სწორი",
    "The given group does not exist" : "მოცემული ჯგუფი არ არსებობს",
    "Check %s is invalid or does not exist" : "შეამოწმეთ %s არასწორია ან არ არსებობს",
    "Operation #%s does not exist" : "ოპერაცია #%s არ არსებობს",
    "Operation %s does not exist" : "ოპერაცია %s არ არსებობს",
    "Operation %s is invalid" : "ოპერაცია %s არაა სწორი",
    "Check %s does not exist" : "შეამოწმეთ %s არ არსებობს",
    "Check %s is invalid" : "შეამოწმეთ %s არასწორია",
    "Check #%s does not exist" : "შეამოწმეთ #%s არ არსებობს",
    "Files workflow engine" : "ფაილების სამუშაოს შესრულების ძრავა",
    "Open documentation" : "ღია დოკუმენტაცია",
    "Loading…" : "იტვირთება...",
    "Workflow" : "შრომითი პროცესები"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/ka_GE.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "მოცემული ოპერატორი არაა სწორი",
    "The given regular expression is invalid" : "მოცემული რეგულარული გამოსახულება არაა სწორი",
    "The given file size is invalid" : "მოცემული ფაილის ზომა არაა სწორი",
    "The given tag id is invalid" : "მოცემული ტეგის id არაა სწორი",
    "The given IP range is invalid" : "მოცემული IP დიაპაზონი არაა სწორი",
    "The given IP range is not valid for IPv4" : "მოცემული IP დიაპაზონი არაა სწორი IPv4-ისთვის",
    "The given IP range is not valid for IPv6" : "მოცემული IP დიაპაზონი არაა სწორი IPv6-ისთვის",
    "The given time span is invalid" : "მოცემული დროის ინტერვალი არაა სწორი",
    "The given start time is invalid" : "მოცემული საწყისი დრო არაა სწორი",
    "The given end time is invalid" : "მოცემული დროის დასასრული არაა სწორი",
    "The given group does not exist" : "მოცემული ჯგუფი არ არსებობს",
    "Operation #%s does not exist" : "ოპერაცია #%s არ არსებობს",
    "Operation %s does not exist" : "ოპერაცია %s არ არსებობს",
    "Operation %s is invalid" : "ოპერაცია %s არაა სწორი",
    "Check %s does not exist" : "შეამოწმეთ %s არ არსებობს",
    "Check %s is invalid" : "შეამოწმეთ %s არასწორია",
    "Check #%s does not exist" : "შეამოწმეთ #%s არ არსებობს",
    "Check %s is invalid or does not exist" : "შეამოწმეთ %s არასწორია ან არ არსებობს",
    "Predefined URLs" : "წინასწარ განსაზღვრული URL-ები",
    "Files WebDAV" : "ფაილები WebDAV",
    "Android client" : "Android კლიენტი",
    "iOS client" : "iOS კლიენტი",
    "Desktop client" : "დესკტოპ კლიენტი",
    "is" : "არის",
    "is not" : "არ არის",
    "matches" : "ემთხვევა",
    "does not match" : "არ ემთხვევა",
    "File MIME type" : "ფაილის MIME სახეობა",
    "File size (upload)" : "ფაილის ზომა (ატვირთვა)",
    "less" : "უფრო ნაკლები",
    "less or equals" : "უფრო ნაკლები ან ტოლი",
    "greater or equals" : "უფრო მეტი ან ტოლი",
    "greater" : "უფრო მეტი",
    "Request remote address" : "დისტანციური მისამართის მოთხოვნა",
    "matches IPv4" : "ემთხვევა IPv4-ს",
    "does not match IPv4" : "არ ემთხვევა IPv4-ს",
    "matches IPv6" : "ემთხვევა IPv6-ს",
    "does not match IPv6" : "არ ემთხვევა IPv6-ს",
    "File system tag" : "ფაილის სისტემური ტეგი",
    "is tagged with" : "დატეგილია როგორც",
    "is not tagged with" : "არაა დატეგილი როგორც",
    "Request URL" : "მოთხოვნის URL",
    "Request time" : "მოთხოვნის დრო",
    "between" : "შორის",
    "not between" : "არა შორის",
    "Request user agent" : "მოთხოვნის მომხმარებლის აგენტი",
    "User group membership" : "მომხმარებლის ჯგუფის წევრიანობა",
    "is member of" : "არის წევრი ჯგუფისა",
    "is not member of" : "არ არის წევრი ჯგუფისა",
    "Short rule description" : "წესის მოკლე აღწერა",
    "Add rule" : "წესის დამატება",
    "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
    "Save" : "შენახვა",
    "Saving…" : "მიმდინარეობს დამახსოვრება...",
    "Saved" : "შენახულია",
    "Saving failed:" : "შენახვა ვერ მოხერხდა:",
    "Add rule group" : "ჯგუფის წესის დამატება",
    "Example: {placeholder}" : "მაგალითი: {placeholder}",
    "Select tag…" : "აირჩიეთ ტეგი...",
    "Start" : "დაწყება",
    "End" : "დამთავრება",
    "Select timezone…" : "აირჩიეთ დროის სარტყელი...",
    "Sync clients" : "სინქ. კლიენტები",
    "Workflow" : "შრომითი პროცესები",
    "Files workflow engine" : "ფაილების სამუშაოს შესრულების ძრავა",
    "Open documentation" : "ღია დოკუმენტაცია",
    "Loading…" : "იტვირთება..."
},
"nplurals=2; plural=(n!=1);");
